#!/usr/bin/env python

"""Tests for `cosmic_variance` package."""


import unittest

from cosmic_variance import cosmic_variance


class TestCosmic_variance(unittest.TestCase):
    """Tests for `cosmic_variance` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_000_something(self):
        """Test something."""
