"""Top-level package for Cosmic Variance."""

__author__ = """Christian Kragh Jespersen"""
__email__ = 'ckragh@princeton.edu'
__version__ = '0.1.2'

from .quickcv import quickcv
from .cosmic_variance import get_cv